#
# Package name and versioning information for Magics
#
MAGICS_PACKAGE_NAME='MagicsNew'
MAGICS_PACKAGE_VERSION='2.20.2'
MAGICS_PACKAGE_COPYRIGHT_YEAR='2013'
MAGICS_PACKAGE_COPYRIGHT_PERIOD='2007-2013'
MAGICS_PACKAGE_RELEASE_DATE=`date +%d-%B-%Y`
#
#
# Libtool library revision control info
# See the libtool documentation under the heading "Libtool's versioning
# system" in order to understand the meaning of these fields
#
# Here are a set of rules to help you update your library version
# information:
#
#  1. Start with version information of `0:0:0' for each libtool library.
#  2. Update the version information only immediately before a public
#     release of your software. More frequent updates are unnecessary, and
#     only guarantee that the current interface number gets larger faster.
#  3. If the library source code has changed at all since the last update,
#     then increment revision (`c:r:a' becomes `c:r+1:a').
#  4. If any interfaces have been added, removed, or changed since the last
#     update, increment current, and set revision to 0.
#  5. If any interfaces have been added since the last public release, then
#     increment age.
#  6. If any interfaces have been removed since the last public release,
#     then set age to 0.
MAGICS_LIBRARY_CURRENT=3
MAGICS_LIBRARY_REVISION=0
MAGICS_LIBRARY_AGE=0
